pecos.machines
==============

.. automodule:: pecos.machines



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.machines.generic_machine
   pecos.machines.machine_abc
